@@ -13,37 +13,58 @@ def clean_path(path):
 	return path
 
 # test ssh functions.
-def test_ssh(alias=None, accept_new_host_keys=True,):
+def test_ssh(alias=None, accept_new_host_keys=True, checks=True):
 	accept_new_host_keys = Formats.Boolean(accept_new_host_keys).convert(true="printf 'yes' | ", false="")
 	output = syst3m.utils.__execute_script__(f"""{accept_new_host_keys}ssh {alias} ' echo "Hello World" ' """)
 	if "Hello World" in output:
 		return r3sponse.success_response(f"Successfully connected with {alias}.")
 	else:
 		return r3sponse.error_response(f"Failed to connect with {alias}, error: {output}")
-def test_ssh_path(alias=None, path=None, accept_new_host_keys=True,):
-	response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
-	if not response.success: return response
+def test_ssh_path(alias=None, path=None, accept_new_host_keys=True, checks=True):
+	if checks:
+		response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
+		if not response.success: return response
 	output = syst3m.utils.__execute_script__(f"""ssh {alias} ' ls -ld {path} ' """)
 	if "No such file or directory" not in output:
 		return r3sponse.success_response(f"Path {alias}:{path} exists.")
 	else:
 		return r3sponse.error_response(f"Path {alias}:{path} does not exist.")
-def test_ssht00ls(alias=None, accept_new_host_keys=True, install=True):
-	path = f"/usr/local/lib/{ALIAS}"
-	response = test_ssh_path(alias=alias, accept_new_host_keys=accept_new_host_keys, path=path)
-	if not response.success:
-		if response.error == f"Path {alias}:{path} does not exist.":
-			if install:
-				loader = syst3m.console.Loader(f"Installing ssht00ls library on remote {alias}.")
-				output = syst3m.utils.__execute_script__(f"ssh {alias} ' curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ' ")
-				response = test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys, install=False)
-				loader.stop(success=response.success)
-				print(output)
-				return response
+def test_ssh_dir(alias=None, path=None, accept_new_host_keys=True, create=False, checks=True):
+	if checks:
+		response = test_ssh(alias=alias, accept_new_host_keys=accept_new_host_keys)
+		if not response.success: return response
+	lpath = "\'"+path+"\'"
+	output = syst3m.utils.__execute_script__(f"""ssh {alias} ''' python3 /usr/local/lib/ssht00ls/classes/utils/isdir.py {path}''' """)
+	if output.replace("\n","") == "directory":
+		return r3sponse.success_response(f"Path {alias}:{path} is a directory.")
+	elif output.replace("\n","") in ["directory", "does-not-exist"]:
+		if output.replace("\n","") in ["does-not-exist"]:
+			if create:
+				output = syst3m.utils.__execute_script__(f"""ssh {alias} ''' mkdir -p {path}''' """)
+				if "permission denied" in output: return r3sponse.error_response(f"Unable to create remote directory [{alias}:{path}].")
+				return test_ssh_dir(alias=alias, path=path, checks=False, create=False)
 			else:
-				return r3sponse.error_response(f"Remote {alias} does not have library ssht00ls installed.")
+				return r3sponse.error_response(f"Path {alias}:{path} does not exist.")
 		else:
-			return response
+			return r3sponse.error_response(f"Path {alias}:{path} is not a directory.")
+	else:
+		return r3sponse.error_response(f"Unable to check remote directory {alias}:{path}, output: {output}.")
+def test_ssht00ls(alias=None, accept_new_host_keys=True, install=True):
+	for path in [f"/usr/local/lib/{ALIAS}"]:
+		response = test_ssh_path(alias=alias, accept_new_host_keys=accept_new_host_keys, path=path)
+		if not response.success:
+			if response.error == f"Path {alias}:{path} does not exist.":
+				if install:
+					loader = syst3m.console.Loader(f"Installing ssht00ls library on remote {alias}.")
+					output = syst3m.utils.__execute_script__(f"ssh {alias} ' curl https://raw.githubusercontent.com/vandenberghinc/{ALIAS}/master/{ALIAS}/requirements/installer.remote | bash ' ")
+					response = test_ssht00ls(alias=alias, accept_new_host_keys=accept_new_host_keys, install=False)
+					loader.stop(success=response.success)
+					print(output)
+					return response
+				else:
+					return r3sponse.error_response(f"Remote {alias} does not have library ssht00ls installed.")
+			else:
+				return response
 	return r3sponse.success_response(f"Remote {alias} has library ssht00ls installed.")
 
 # check / start the ssh agent.
